@@ -99,8 +99,6 @@ class ShopifyBookService:
             operation_name="productVariantByISBN",
         )
         data = json.loads(result)
-        edges = data["data"]["productVariants"]["edges"]
-        print(edges)
         has_book = len(data["data"]["productVariants"]["edges"]) > 0
         return has_book
 
